package com.ruoyi.bst.remind.service.impl;


import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;
import java.util.List;

import com.ruoyi.common.constants.RemindConstants;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.remind.mapper.RemindMapper;
import com.ruoyi.bst.remind.domain.Remind;
import com.ruoyi.bst.remind.domain.RemindVO;
import com.ruoyi.bst.remind.domain.RemindQuery;
import com.ruoyi.bst.remind.service.RemindService;

/**
 * 定时提醒Service业务层处理
 *
 * @author ruoyi
 * @date 2025-06-10
 */
@Service
public class RemindServiceImpl implements RemindService
{
    @Autowired
    private RemindMapper remindMapper;

    /**
     * 查询定时提醒
     *
     * @param id 定时提醒主键
     * @return 定时提醒
     */
    @Override
    public RemindVO selectRemindById(Long id)
    {
        return remindMapper.selectRemindById(id);
    }

    /**
     * 查询定时提醒列表
     *
     * @param remind 定时提醒
     * @return 定时提醒
     */
    @Override
    public List<RemindVO> selectRemindList(RemindQuery remind)
    {
        return remindMapper.selectRemindList(remind);
    }

    /**
     * 新增定时提醒
     *
     * @param remind 定时提醒
     * @return 结果
     */
    @Override
    public int insertRemind(Remind remind)
    {
        remind.setIsInvalid(RemindConstants.ON);
        remind.setReminderNumber(0L);
        Long userId = SecurityUtils.getUserId();
        Date now = Date.from(LocalDateTime.now().atZone(ZoneId.systemDefault()).toInstant());
        remind.setCreateId(userId);
        remind.setCreataDate(now);
        remind.setUpdateId(userId);
        remind.setUpdateDate(now);
        return remindMapper.insertRemind(remind);
    }

    /**
     * 修改定时提醒
     *
     * @param remind 定时提醒
     * @return 结果
     */
    @Override
    public int updateRemind(Remind remind)
    {
        Long userId = SecurityUtils.getUserId();
        remind.setUpdateId(userId);
        Date nowDate = DateUtils.getNowDate();
        remind.setUpdateDate(nowDate);
        return remindMapper.updateRemind(remind);
    }

    /**
     * 批量删除定时提醒
     *
     * @param ids 需要删除的定时提醒主键
     * @return 结果
     */
    @Override
    public int deleteRemindByIds(Long[] ids)
    {
        return remindMapper.deleteRemindByIds(ids);
    }

    /**
     * 删除定时提醒信息
     *
     * @param id 定时提醒主键
     * @return 结果
     */
    @Override
    public int deleteRemindById(Long id)
    {
        return remindMapper.deleteRemindById(id);
    }

    @Override
    public List<RemindVO> selectEveryDay() {
        return remindMapper.selectEveryDay();
    }

    @Override
    public List<RemindVO> selectNotEveryDay() {
        return remindMapper.selectNotEveryDay();
    }

    @Override
    public int batchUpdate(List<Remind> list) {
        return remindMapper.batchUpdate(list);
    }

}
