package com.ruoyi.task;

import com.ruoyi.bst.message.domain.Message;
import com.ruoyi.bst.message.domain.enums.MessageBstType;
import com.ruoyi.bst.message.service.MessageService;
import com.ruoyi.bst.remind.domain.Remind;
import com.ruoyi.bst.remind.domain.RemindVO;
import com.ruoyi.bst.remind.service.RemindService;
import com.ruoyi.common.constants.RemindConstants;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import sun.util.resources.LocaleData;


import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

@Component
@Slf4j
public class RemindTask {

    @Autowired
    private RemindService remindService;

    @Autowired
    private MessageService messageService;

    /**
     * 每个小时执行
     * 处理每天到期提醒功能
     * 到规定时间后，往消息表插入消息
     */
    public void handleEveryDayExpirationReminder() {
        List<Message> messages = new ArrayList<>();
        List<Remind> remindS = new ArrayList<>();
        List<RemindVO> list = remindService.selectEveryDay();
        for (RemindVO remindVO : list) {
            Date now = DateUtils.getNowDate();
            int i = now.compareTo(remindVO.getNextRemindTime());
            if (i > 0) {
                // 配置Message对象
                Message message = new Message();
                message.setUserId(remindVO.getCreateId());
                message.setBstType(MessageBstType.TASK.getValue());
                // 业务id
                message.setBstId(21L);

                message.setTitle(RemindConstants.TITLE[Integer.parseInt(remindVO.getProjectType())]);

                message.setContent(remindVO.getNotes());
                messages.add(message);
                // 使用 Calendar 增加1小时
                Calendar calendar = Calendar.getInstance();
                calendar.setTime(now);
                calendar.add(Calendar.HOUR_OF_DAY, 1); // 增加1小时
                Date nextDate = calendar.getTime();
                // 更新
                remindVO.setReminderNumber(remindVO.getReminderNumber()+1);
                remindVO.setLastReminderTime(now);
                remindVO.setNextRemindTime(nextDate);
                remindS.add(remindVO);
            }
        }
        if (!remindS.isEmpty())
            remindService.batchUpdate(remindS);

        if (!messages.isEmpty())
            messageService.batchInsert(messages);
    }

    /**
     * 每天8:30执行一次
     * 处理非每天到期提醒功能
     * 到规定时间后，往消息表插入消息
     */
    public void handleNotEveryDayExpirationReminder() {
        List<Message> messages = new ArrayList<>();
        List<Remind> remindS = new ArrayList<>();
        for (RemindVO remindVO : remindService.selectNotEveryDay()) {
            Date now = DateUtils.getNowDate();
            int i = now.compareTo(remindVO.getLastReminderTime());
            if (i > 0) {
                Message message = new Message();
                message.setUserId(remindVO.getCreateId());
                message.setBstType(MessageBstType.TASK.getValue());
                // 业务id
                message.setBstId(21L);
                message.setTitle(RemindConstants.TITLE[Integer.parseInt(remindVO.getProjectType())]);
                message.setContent(remindVO.getNotes());
                messages.add(message);

                Calendar calendar = Calendar.getInstance();
                calendar.setTime(now);
                Date nextDate = null;
                if (remindVO.getReminderPattern().equals(RemindConstants.MONTHLY)) {
                    calendar.add(Calendar.MONTH, 1); // 增加1个月
                    nextDate = calendar.getTime();
                }
                if (remindVO.getReminderPattern().equals(RemindConstants.EVERYYEAR)) {
                    calendar.add(Calendar.YEAR, 1); // 增加1年
                    nextDate = calendar.getTime();
                }

                // 更新
                remindVO.setReminderNumber(remindVO.getReminderNumber()+1);
                remindVO.setLastReminderTime(now);
                if (remindVO.getReminderPattern().equals(RemindConstants.NEXTREMINDER)) {
                    remindVO.setIsInvalid(RemindConstants.OFF);
                } else {
                    remindVO.setNextRemindTime(nextDate);
                }

                remindS.add(remindVO);
            }
        }
        remindService.batchUpdate(remindS);
        messageService.batchInsert(messages);

    }

}
