package com.ruoyi.web.bst;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.bst.remind.domain.Remind;
import com.ruoyi.bst.remind.domain.RemindVO;
import com.ruoyi.bst.remind.domain.RemindQuery;
import com.ruoyi.bst.remind.service.RemindService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 定时提醒Controller
 *
 * @author ruoyi
 * @date 2025-06-11
 */
@RestController
@RequestMapping("/bst/remind")
public class RemindController extends BaseController
{
    @Autowired
    private RemindService remindService;

    /**
     * 查询定时提醒列表
     */
    @PreAuthorize("@ss.hasPermi('bst:remind:list')")
    @GetMapping("/list")
    public TableDataInfo list(RemindQuery query)
    {
        startPage();
        startOrderBy();
        List<RemindVO> list = remindService.selectRemindList(query);
        return getDataTable(list);
    }

    /**
     * 导出定时提醒列表
     */
    @PreAuthorize("@ss.hasPermi('bst:remind:export')")
    @Log(title = "定时提醒", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RemindQuery query)
    {
        List<RemindVO> list = remindService.selectRemindList(query);
        ExcelUtil<RemindVO> util = new ExcelUtil<RemindVO>(RemindVO.class);
        util.exportExcel(response, list, "定时提醒数据");
    }

    /**
     * 获取定时提醒详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:remind:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(remindService.selectRemindById(id));
    }

    /**
     * 新增定时提醒
     */
    @PreAuthorize("@ss.hasPermi('bst:remind:add')")
    @Log(title = "定时提醒", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Remind remind)
    {
        return toAjax(remindService.insertRemind(remind));
    }

    /**
     * 修改定时提醒
     */
    @PreAuthorize("@ss.hasPermi('bst:remind:edit')")
    @Log(title = "定时提醒", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Remind remind)
    {
        return toAjax(remindService.updateRemind(remind));
    }

    /**
     * 删除定时提醒
     */
    @PreAuthorize("@ss.hasPermi('bst:remind:remove')")
    @Log(title = "定时提醒", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(remindService.deleteRemindByIds(ids));
    }
}
